# Note: King concentration index, core radius, and distance for NGC 121 are from here:
# Structural Parameters of Seven Small Magellanic Cloud Intermediate-Age and Old Star 
# Clusters
# http://adsabs.harvard.edu/abs/2009AJ....138.1403G
# These were fit to surface-brightness profiles.
#
# Distance moduli are from this source:
# "Blue Straggler Stars beyond the Milky Way. II. A Binary Origin for Blue Straggler 
# Stars in Magellanic Cloud Clusters"
# https://iopscience.iop.org/article/10.3847/1538-4357/aacc6b
# and
# "Exploring the nature and synchronicity of early cluster formation in the Large 
# Magellanic Cloud - II. Relative ages and distances for six ancient globular clusters"
# https://arxiv.org/abs/1707.01571
# For LW 220, this source was used:
# "The low-mass stellar-mass functions of rich, compact clusters in the Large Magellanic 
# Cloud"
# https://arxiv.org/abs/0905.3698
# 
# Structural parameters from this source:
# "Resolved Massive Star Clusters in the Milky Way and Its Satellites: Brightness Profiles 
# and a Catalog of Fundamental Parameters"
# https://iopscience.iop.org/article/10.1086/497429
# For ESO 57-30, they come from here:
# "An Analysis of the Population of Extended Main Sequence Turn-off Clusters in the Large 
# Magellanic Cloud"
# https://academic.oup.com/mnras/article/463/2/1632/2892500
# For NGC 1644, NGC 1783, and NGC 1806 they come from here:
# "Blue Straggler Stars Beyond the Milky Way. III. Detection of Evolved Blue Straggler 
# Candidates in Large Magellanic Cloud Clusters"
# https://iopscience.iop.org/article/10.3847/1538-3881/aad463
# For Reticulum, the parameters come from:
# "Evidence of differential tidal effects in the old globular cluster population of the 
# Large Magellanic Cloud"
# https://arxiv.org/abs/1804.09549
# 
# Magnitudes are from SIMBAD, or if lacking, from this source:
# "The Star Clusters of the Large Magellanic Cloud: Structural Parameters"
# https://iopscience.iop.org/article/10.1088/0004-6256/142/2/48

# SMC
Globular "NGC 121:ESO 50-12"
{
	 RA             0.4478528  # hours
	 Dec          -71.5225806  # degrees
	 Distance        2.12e+05  # ly
	 Radius               175  # ly (from 3.5 arcmin)
	 CoreRadius           0.2  # arcmin
	 KingConcentration   1.25  # c = log10(r_t/r_c)
	 AbsMag           -7.6871  # V mags
	 Axis       	[ -0.7429  -0.2364  -0.6263]
	 Angle       	    175.9  # degrees
	 InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+121"
}

# LMC
Globular "NGC 1466:ESO 54-16:KMHK 1:LW 1"
{
	RA               3.74253  # [hours]
	Dec             -71.6720  # [degrees]
	Distance       1.583e+05  # [ly], DM = 18.43
	Radius                83  # [ly]
	CoreRadius         0.191  # [arcmin]
	KingConcentration   1.11  # c = log(r_t/r_c)
	AbsMag           -6.8403  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1466"
}

Globular "NGC 1629:ESO 55-24:KMHK 4:LW 3"
{
	RA                 4.493  # [hours]
	Dec             -71.8380  # [degrees]
	Distance       2.089e+05  # [ly], guess
	Radius                40  # [ly]
	CoreRadius         0.207  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -6.3556  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1629"
}

Globular "Reticulum Cluster:KMHK 10"
{
	RA              4.603167  # [hours]
	Dec             -58.8631  # [degrees]
	Distance       1.576e+05  # [ly], DM = 18.42
	Radius               111  # [ly]
	CoreRadius         1.339  # [arcmin]
	KingConcentration   0.78  # c = log(r_t/r_c)
	AbsMag           -4.1707  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NAME Ret"
}

Globular "NGC 1651:ESO 55-30:KMHK 20:LW 12"
{
	RA             4.6257028  # [hours]
	Dec           -70.585753  # [degrees]
	Distance       1.620e+05  # [ly], DM = 18.48
	Radius                64  # [ly]
	CoreRadius         0.271  # [arcmin]
	KingConcentration   1.44  # c = log(r_t/r_c)
	AbsMag           -6.2004  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1651"
}

Globular "NGC 1644:ESO 84-30:KMHK 18:LW 11"
{
	RA               4.62753  # [hours]
	Dec             -66.2000  # [degrees]
	Distance       1.620e+05  # [ly], DM = 18.48
	Radius                43  # [ly]
	CoreRadius         0.072  # [arcmin]
	KingConcentration   1.27  # c = log(r_t/r_c)
	AbsMag           -5.5904  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1644"
}

Globular "NGC 1652:ESO 55-32:KMHK 23:LW 14"
{
	RA              4.639725  # [hours]
	Dec           -68.672364  # [degrees]
	Distance       1.620e+05  # [ly], DM = 18.48
	Radius                36  # [ly]
	CoreRadius         0.266  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -5.3504  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1652"
}

Globular "NGC 1841:ESO 4-15:NGC 1841"
{
	RA                4.7564  # [hours]
	Dec             -83.9970  # [degrees]
	Distance       1.547e+05  # [ly], DM = 18.38
	Radius                21  # [ly]
	CoreRadius         0.865  # [arcmin]
	KingConcentration   0.57  # c = log(r_t/r_c)
	AbsMag           -6.9503  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1841"
}

Globular "NGC 1696:ESO 56-4:KMHK 108"
{
	RA            4.80823887  # [hours]
	Dec           -68.242583  # [degrees]
	Distance       1.721e+05  # [ly], guess
	Radius                26  # [ly]
	CoreRadius         0.251  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -4.6618  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1696"
}

Globular "NGC 1756:ESO 56-27:KMHK 257"
{
	RA             4.9136472  # [hours]
	Dec           -69.236167  # [degrees]
	Distance       1.834e+05  # [ly], guess
	Radius                33  # [ly]
	CoreRadius         0.235  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -6.5099  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1756"
}

Globular "NGC 1783:ESO 85-29:KMHK 383:HD 270921"
{
	RA            4.98571947  # [hours]
	Dec           -65.987733  # [degrees]
	Distance       1.605e+05  # [ly], DM = 18.46
	Radius               126  # [ly]
	CoreRadius         0.327  # [arcmin]
	KingConcentration   1.59  # c = log(r_t/r_c)
	AbsMag           -7.5302  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1783"
}

Globular "NGC 1806:ESO 56-47:KMHK 462"
{
	RA            5.03643887  # [hours]
	Dec           -67.984969  # [degrees]
	Distance       1.620e+05  # [ly], DM = 18.48
	Radius                59  # [ly]
	CoreRadius         0.235  # [arcmin]
	KingConcentration   1.19  # c = log(r_t/r_c)
	AbsMag           -7.3804  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1806"
}

Globular "NGC 1805:ESO 85-32:KMHK 459"
{
	RA            5.03935833  # [hours]
	Dec           -66.110953  # [degrees]
	Distance       1.696e+05  # [ly], guess
	Radius                43  # [ly]
	CoreRadius         0.089  # [arcmin]
	KingConcentration   1.28  # c = log(r_t/r_c)
	AbsMag           -7.5800  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1805"
}

Globular "NGC 1818:ESO 85-40:KMHK 491"
{
	RA            5.07036113  # [hours]
	Dec           -66.434853  # [degrees]
	Distance       1.636e+05  # [ly], guess
	Radius                73  # [ly]
	CoreRadius         0.150  # [arcmin]
	KingConcentration   1.41  # c = log(r_t/r_c)
	AbsMag           -8.7018  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1818"
}

Globular "NGC 1831:ESO 85-44:KMHK 530:LW 133"
{
	RA              5.104833  # [hours]
	Dec             -64.9197  # [degrees]
	Distance       1.561e+05  # [ly], DM = 18.40
	Radius                90  # [ly]
	CoreRadius         0.325  # [arcmin]
	KingConcentration   1.18  # c = log(r_t/r_c)
	AbsMag           -7.2199  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1831"
}

Globular "NGC 1866:ESO 85-52:KMHK 664:LW 163"
{
	RA             5.2274778  # [hours]
	Dec           -65.464653  # [degrees]
	Distance       1.559e+05  # [ly], guess
	Radius               130  # [ly]
	CoreRadius         0.209  # [arcmin]
	KingConcentration   1.65  # c = log(r_t/r_c)
	AbsMag           -8.6671  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1866"
}

Globular "NGC 1868:ESO 85-56:KMHK 674:LW 169"
{
	RA                5.2433  # [hours]
	Dec             -63.9550  # [degrees]
	Distance       1.561e+05  # [ly], DM = 18.40
	Radius                64  # [ly]
	CoreRadius         0.105  # [arcmin]
	KingConcentration   1.36  # c = log(r_t/r_c)
	AbsMag           -6.8299  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1868"
}

Globular "NGC 1987:ESO 56-131:KMHK 926"
{
	RA            5.45470553  # [hours]
	Dec           -70.737267  # [degrees]
	Distance       1.554e+05  # [ly], guess
	Radius                40  # [ly]
	CoreRadius         0.278  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -6.2901  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1987"
}

Globular "2MASX J05283953-7337514:KMHK 967:LW 220"
{
	RA            5.47764747  # [hours]
	Dec           -73.630958  # [degrees]
	Distance       1.627e+05  # [ly], DM = 18.49
	Radius                17  # [ly]
	CoreRadius         0.123  # [arcmin]
	KingConcentration   1.56  # c = log(r_t/r_c)
	AbsMag           -5.0698  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2MASX J05283953-7337514"
}

Globular "NGC 1978:ESO 85-90:KMHK 944"
{
	RA            5.47925833  # [hours]
	Dec           -66.236678  # [degrees]
	Distance       1.673e+05  # [ly], DM = 18.55
	Radius                95  # [ly]
	CoreRadius         0.258  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -7.8504  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 1978"
}

Globular "Hodge 4:ESO 86-9:KMHK 1034:LW 237"
{
	RA               5.54028  # [hours]
	Dec             -64.7364  # [degrees]
	Distance       1.652e+05  # [ly], guess
	Radius                59  # [ly]
	CoreRadius         0.238  # [arcmin]
	KingConcentration   2.46  # c = log(r_t/r_c)
	AbsMag           -5.1929  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Hodge 4"
}

Globular "Hodge 3:KMHK 1065"
{
	RA             5.5554722  # [hours]
	Dec           -68.152008  # [degrees]
	Distance       1.770e+05  # [ly], guess
	Radius                43  # [ly]
	CoreRadius         0.244  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -5.2527  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Hodge 3"
}

Globular "NGC 2031:ESO 56-153:KMHK 1084"
{
	RA            5.56151113  # [hours]
	Dec           -70.987372  # [degrees]
	Distance       1.606e+05  # [ly], guess
	Radius                78  # [ly]
	CoreRadius         0.220  # [arcmin]
	KingConcentration   1.50  # c = log(r_t/r_c)
	AbsMag           -7.6316  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2031"
}

Globular "ESO 57-19:KMHK 1219:LW 268"
{
	RA            5.66955833  # [hours]
	Dec           -72.192056  # [degrees]
	Distance       1.565e+05  # [ly], guess
	Radius                36  # [ly]
	CoreRadius         0.276  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -5.1054  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=ESO 57-19"
}

Globular "ESO 57-30:KMHK 1275:LW 274"
{
	RA            5.70480553  # [hours]
	Dec           -71.590964  # [degrees]
	Distance       1.640e+05  # [ly], guess
	Radius                47  # [ly]
	CoreRadius         0.267  # [arcmin]
	KingConcentration   0.87  # c = log(r_t/r_c)
	AbsMag           -6.4171  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=ESO 57-30"
}

Globular "NGC 2108:ESO 57-33:KMHK 1304"
{
	RA             5.7322972  # [hours]
	Dec           -69.181769  # [degrees]
	Distance       1.600e+05  # [ly], guess
	Radius                43  # [ly]
	CoreRadius         0.270  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -6.1335  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2108"
}

Globular "ESO 57-43:KMHK 1424"
{
	RA                5.8343  # [hours]
	Dec           -67.718414  # [degrees]
	Distance       1.766e+05  # [ly], guess
	Radius                55  # [ly]
	CoreRadius         0.244  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -6.4078  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=ESO 57-43"
}

Globular "ESO 57-50:KMHK 1505"
{
	RA            5.90059447  # [hours]
	Dec           -67.735031  # [degrees]
	Distance       1.727e+05  # [ly], guess
	Radius                50  # [ly]
	CoreRadius         0.250  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -5.8493  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=ESO 57-50"
}

Globular "ESO 57-56:KMHK 1540"
{
	RA            5.93378613  # [hours]
	Dec           -70.338219  # [degrees]
	Distance       1.541e+05  # [ly], guess
	Radius                43  # [ly]
	CoreRadius         0.280  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -5.7019  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=ESO 57-56"
}

Globular "NGC 2156:ESO 57-59:KMHK 1560"
{
	RA               5.96253  # [hours]
	Dec             -68.4600  # [degrees]
	Distance       1.761e+05  # [ly], guess
	Radius                50  # [ly]
	CoreRadius         0.092  # [arcmin]
	KingConcentration   1.44  # c = log(r_t/r_c)
	AbsMag           -7.2817  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2156"
}

Globular "NGC 2159:ESO 57-60:KMHK 1561"
{
	RA                5.9658  # [hours]
	Dec             -68.6230  # [degrees]
	Distance       1.743e+05  # [ly], guess
	Radius                45  # [ly]
	CoreRadius         0.122  # [arcmin]
	KingConcentration   1.44  # c = log(r_t/r_c)
	AbsMag           -7.2594  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2159"
}

Globular "NGC 2173:ESO 33-34:KMHK 1570:LW 348"
{
	RA               5.96613  # [hours]
	Dec             -72.9780  # [degrees]
	Distance       1.597e+05  # [ly], DM = 18.45
	Radius                62  # [ly]
	CoreRadius         0.201  # [arcmin]
	KingConcentration   1.52  # c = log(r_t/r_c)
	AbsMag           -6.5694  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2173"
}

Globular "NGC 2162:ESO 86-47:KMHK 1579:LW 351"
{
	RA                6.0086  # [hours]
	Dec             -63.7220  # [degrees]
	Distance       1.647e+05  # [ly], guess
	Radius                71  # [ly]
	CoreRadius         0.172  # [arcmin]
	KingConcentration   1.28  # c = log(r_t/r_c)
	AbsMag           -5.8163  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2162"
}

Globular "NGC 2190:ESO 33-36:KMHK 1601:LW 357"
{
	RA                6.0172  # [hours]
	Dec             -74.7270  # [degrees]
	Distance       1.681e+05  # [ly], guess
	Radius                52  # [ly]
	CoreRadius         0.257  # unknown, used average of the rest
	KingConcentration   1.34  # unknown, used average of the rest
	AbsMag           -5.6207  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2190"
}

Globular "NGC 2209:ESO 34-6:KMHK 1669:LW 408"
{
	RA                6.1428  # [hours]
	Dec             -73.8420  # [degrees]
	Distance       1.597e+05  # [ly], DM = 18.45
	Radius                69  # [ly]
	CoreRadius         0.381  # [arcmin]
	KingConcentration   1.68  # c = log(r_t/r_c)
	AbsMag           -5.2994  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2209"
}

Globular "NGC 2210:ESO 57-71:KMHK 1682:LW 423:HD 272034"
{
	RA              6.192027  # [hours]
	Dec             -69.1214  # [degrees]
	Distance       1.519e+05  # [ly], DM = 18.34
	Radius                24  # [ly]
	CoreRadius         0.148  # [arcmin]
	KingConcentration   1.11  # c = log(r_t/r_c)
	AbsMag           -7.4007  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2210"
}

Globular "Hodge 11:KMHK 1700:LW 437"
{
	RA                6.2397  # [hours]
	Dec            -69.84858  # [degrees]
	Distance       1.635e+05  # [ly], DM = 18.50
	Radius                64  # [ly]
	CoreRadius         0.240  # [arcmin]
	KingConcentration   1.26  # c = log(r_t/r_c)
	AbsMag           -6.5705  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Hodge 11"
}

Globular "NGC 2231:ESO 87-6:KMHK 1737:LW 466"
{
	RA             6.3453136  # [hours]
	Dec             -67.5186  # [degrees]
	Distance       1.769e+05  # [ly], guess
	Radius                13  # [ly]
	CoreRadius         0.216  # [arcmin]
	KingConcentration   1.36  # c = log(r_t/r_c)
	AbsMag           -5.4715  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2231"
}

Globular "NGC 2249:ESO 57-82:KMHK 1755:LW 479"
{
	RA               6.43027  # [hours]
	Dec             -68.9200  # [degrees]
	Distance       1.561e+05  # [ly], DM = 18.40
	Radius                55  # [ly]
	CoreRadius         0.137  # [arcmin]
	KingConcentration   1.21  # c = log(r_t/r_c)
	AbsMag           -6.1699  # [V mags]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC 2249"
}
